# Generated by Django 4.2.20 on 2026-01-06 02:48

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("georgeforge", "0026_remove_order_on_behalf_of"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="estimated_delivery_date",
            field=models.CharField(
                default="",
                help_text="Estimated date when the order will be delivered",
                max_length=50,
                verbose_name="Estimated Delivery Date",
            ),
        ),
    ]
